DataModel class

Annotations
  • @HiveType.new(typeId: 0)

Constructors

DataModel({required int id, required String data})
DataModel.fromMap(Map<String, dynamic> map)
factory

Properties

data String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited